:mod:`art.estimators.classification`
====================================
.. automodule:: art.estimators.classification

Mixin Base Class Classifier
---------------------------
.. autoclass:: ClassifierMixin
   :members:

Mixin Base Class Class Gradients
--------------------------------
.. autoclass:: ClassGradientsMixin
   :members:

BlackBox Classifier
-------------------
.. autoclass:: BlackBoxClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Keras Classifier
----------------
.. autoclass:: KerasClassifier
   :members:
   :special-members: __init__
   :inherited-members:

MXNet Classifier
----------------
.. autoclass:: MXClassifier
   :members:
   :special-members: __init__
   :inherited-members:

PyTorch Classifier
------------------
.. autoclass:: PyTorchClassifier
   :members:
   :special-members: __init__
   :inherited-members:

TensorFlow Classifier
---------------------
.. autoclass:: TensorFlowClassifier
   :members:
   :special-members: __init__
   :inherited-members:

TensorFlow v2 Classifier
------------------------
.. autoclass:: TensorFlowV2Classifier
   :members:
   :special-members: __init__
   :inherited-members:

Ensemble Classifier
-------------------
.. autoclass:: EnsembleClassifier
   :members:
   :special-members: __init__
   :inherited-members:

Scikit-learn Classifier Classifier
----------------------------------
.. autofunction:: SklearnClassifier

GPy Gaussian Process Classifier
-------------------------------
.. autoclass:: GPyGaussianProcessClassifier
   :members:
   :special-members: __init__
   :inherited-members:
